@@ -9,20 +9,12 @@ makedocs(sitename = "QuasiMonteCarlo.jl",
     authors = "Chris Rackauckas",
     modules = [QuasiMonteCarlo],
     clean = true, doctest = false, linkcheck = true,
-    strict = [
-        :doctest,
-        :linkcheck,
-        :parse_error,
-        :example_block,
-        # Other available options are
-        # :autodocs_block, :cross_references, :docs_block, :eval_block, :example_block, :footnote, :meta_block, :missing_docs, :setup_block
-    ],
+    warnonly = [:missing_docs],
     linkcheck_ignore = [
         "https://www.sciencedirect.com/science/article/pii/S0010465509003087",
         "https://artowen.su.domains/mc/qmcstuff.pdf",
     ],
-    format = Documenter.HTML(analytics = "UA-90474609-3",
-        assets = ["assets/favicon.ico"],
+    format = Documenter.HTML(assets = ["assets/favicon.ico"],
         canonical = "https://docs.sciml.ai/QuasiMonteCarlo/stable/"),
     pages = pages)
 
